@@ -5,7 +5,7 @@
 %%% Created : 17 Dec 2013 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2022 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2024 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -121,6 +121,9 @@ tag_with_tags_test() ->
 				    {xmlcdata, <<"cdata2">>}]},
 		 fxml_stream:parse_element(<<"<root><a/>cdata1<b/>cdata2</root>">>)).
 
+use_maps_test() ->
+    ?assertEqual(#{'__struct__' => 'Elixir.FastXML.El', name => <<"root">>, attrs => #{}, children => []}, fxml_stream:parse_element(<<"<root></root>">>, [use_maps])).
+
 receiver(Acc) ->
     receive
 	{'$gen_event', Msg} ->
